@@ -4,7 +4,7 @@
 # hashcash.pl - Wallet for HashCash Digital Cash
 # Copyright (c) 2001-2017 Ashish Gulhati <crypt-hashcash at hash.neo.tc>
 #
-# $Id: bin/hashcash.pl v1.121 Wed Jun 14 11:55:20 PDT 2017 $
+# $Id: bin/hashcash.pl v1.122 Thu Jun 15 19:09:17 PDT 2017 $
 
 use warnings;
 
@@ -67,9 +67,7 @@ $action{Buy} = sub {   # Buy HashCash
   }
   if ($choice == 0) {
     my $dialog = Wx::TextEntryDialog->new( $frame, ('Amount to buy (in Satoshi)'), _('Buy coins'));
-    if($dialog->ShowModal == wxID_CANCEL) {
-      return;
-    };
+    return if $dialog->ShowModal == wxID_CANCEL;
     $amt = $dialog->GetValue();
     return unless $amt and $amt !~ /\D/;
     if ($amt % $client->denoms->[0]) {
@@ -658,7 +656,7 @@ EVT_CHOICE($frame, $langsel, $action{LangSel});
 
 show();
 $statusBar->SetStatusText(_('HashCash Wallet Ready'), 0);
-$frame->Show;
+$frame->Show; $frame->Centre(wxBOTH); $frame->Refresh;
 $app->MainLoop;
 
 # Helper functions
@@ -696,7 +694,7 @@ sub show {                  # Update the wallet view
   $stash->balance($total); $stash->balance_u($total_u);
 
   $label->SetLabel(_('Balance:') . ' ' . _($total)); $label2->SetLabel("Unverified: $total_u");
-  $label->CentreOnParent(wxHORIZONTAL); $label2->CentreOnParent(wxHORIZONTAL);
+  $label->CentreOnParent(wxHORIZONTAL); $label2->CentreOnParent(wxHORIZONTAL); $label2->SetForegroundColour(wxRED);
   $label2->Show($total_u);
 
   my $bottom = $topSizer->GetMinSize->GetHeight;
@@ -716,7 +714,6 @@ sub show {                  # Update the wallet view
   $frame->SetMaxSize($windowsize);
   $frame->SetMinSize($windowsize);
   $frame->SetSize($windowsize);
-  $frame->Centre(wxBOTH);
   $frame->Refresh;
 }
 
@@ -1051,8 +1048,8 @@ hashcash.pl - Wallet for HashCash digital cash
 
 =head1 VERSION
 
- $Revision: 1.121 $
- $Date: Wed Jun 14 11:55:20 PDT 2017 $
+ $Revision: 1.122 $
+ $Date: Thu Jun 15 19:09:17 PDT 2017 $
 
 =head1 SYNOPSIS
 
