@@ -4,7 +4,7 @@
 # vault.pl - Vault server for HashCash Digital Cash
 # Copyright (c) 2017 Ashish Gulhati <crypt-hashcash at hash.neo.tc>
 #
-# $Id: bin/vault.pl v1.121 Wed Jun 14 11:55:20 PDT 2017 $
+# $Id: bin/vault.pl v1.122 Thu Jun 15 19:09:17 PDT 2017 $
 
 use strict;
 use warnings;
@@ -36,12 +36,14 @@ unless (-d "$HASHCASH/vaults") {
 my $vault = new Crypt::HashCash::Vault::Bitcoin ( DB => "$HASHCASH/vault.db",
 						  KeyDB => "$HASHCASH/vaults/vault.key" );
 
-if (defined $ARGV[0] and $ARGV[0] eq '--keygen') {
+if (!-f "$HASHCASH/vaults/vault.key" or (defined $ARGV[0] and $ARGV[0] eq '--keygen')) {
+  $|=1;
+  print STDERR "Generating vault keys... ";
   $vault->keygen( Name   => 'localhost',
 		  Server => 'localhost',
 		  Port   => '20203',
 		  Fees   => { mf => 50, mp => 0, vf => 50, vp => 0.001 } );
-  exit;
+  print "done.\n";
 }
 
 $vault->mint->loadkeys();
@@ -96,8 +98,8 @@ vault.pl - Vault for HashCash Digital Cash
 
 =head1 VERSION
 
- $Revision: 1.121 $
- $Date: Wed Jun 14 11:55:20 PDT 2017 $
+ $Revision: 1.122 $
+ $Date: Thu Jun 15 19:09:17 PDT 2017 $
 
 =head1 SYNOPSIS
 
