@@ -3,7 +3,7 @@
 # Crypt::HashCash::CoinRequest - HashCash Digital Cash Coin Request
 # Copyright (c) 2001-2017 Ashish Gulhati <crypt-hashcash at hash.neo.tc>
 #
-# $Id: lib/Crypt/HashCash/CoinRequest.pm v1.121 Wed Jun 14 11:55:20 PDT 2017 $
+# $Id: lib/Crypt/HashCash/CoinRequest.pm v1.122 Thu Jun 15 19:09:17 PDT 2017 $
 
 package Crypt::HashCash::CoinRequest;
 
@@ -14,7 +14,7 @@ use Crypt::HashCash qw (_dec _hex);
 use Compress::Zlib;
 use vars qw( $VERSION $AUTOLOAD );
 
-our ( $VERSION ) = '$Revision: 1.121 $' =~ /\s+([\d\.]+)/;
+our ( $VERSION ) = '$Revision: 1.122 $' =~ /\s+([\d\.]+)/;
 
 sub from_string {
   my ($class, $str) = @_; $str =~ s/\s*$//;
@@ -58,12 +58,12 @@ __END__
 
 =head1 NAME
 
-Crypt::HashCash::CoinRequest - HashCash Digital Dash Doin Request
+Crypt::HashCash::CoinRequest - HashCash Digital Cash Coin Request
 
 =head1 VERSION
 
- $Revision: 1.121 $
- $Date: Wed Jun 14 11:55:20 PDT 2017 $
+ $Revision: 1.122 $
+ $Date: Thu Jun 15 19:09:17 PDT 2017 $
 
 =head1 SYNOPSIS
 
