@@ -3,7 +3,7 @@
 # Crypt::HashCash::Vault::Bitcoin - Bitcoin Vault for HashCash Digital Cash
 # Copyright (c) 2017 Ashish Gulhati <crypt-hashcash at hash.neo.tc>
 #
-# $Id: lib/Crypt/HashCash/Vault/Bitcoin.pm v1.121 Wed Jun 14 11:55:20 PDT 2017 $
+# $Id: lib/Crypt/HashCash/Vault/Bitcoin.pm v1.122 Thu Jun 15 19:09:17 PDT 2017 $
 
 package Crypt::HashCash::Vault::Bitcoin;
 
@@ -20,7 +20,7 @@ use Business::Bitcoin;
 use Authen::TuringImage;
 use vars qw( $VERSION $AUTOLOAD );
 
-our ( $VERSION ) = '$Revision: 1.121 $' =~ /\s+([\d\.]+)/;
+our ( $VERSION ) = '$Revision: 1.122 $' =~ /\s+([\d\.]+)/;
 
 sub new {
   my ($class, %arg) = @_;
@@ -415,15 +415,25 @@ sub process_request {                                 # Hande a request from a c
 				  Coins              => [ map { Crypt::HashCash::Coin->from_string($_) } split / /,$2 ],
 				  Requests           => [ map { Crypt::HashCash::CoinRequest->from_string($_) } split / /,$3 ],
 				  ChangeRequests     => [ map { Crypt::HashCash::CoinRequest->from_string($_) } split / /,$4 ]);
-    my @bcoins = map { $_->as_string } @$bcoins;
-    $ret = "@bcoins";
+    if ($bcoins =~ /^-E/) {
+      $ret = $bcoins;
+    }
+    else {
+      my @bcoins = map { $_->as_string } @$bcoins;
+      $ret = "@bcoins";
+    }
   }
   elsif (/^e (\S+) (.+) r (.+)$/) {                   # Exchange ( [#] > [#] ), no change request(s)
     my $bcoins = $self->exchange( FeeDenoms          => { split /[,:]/, $1 },
 				  Coins              => [ map { Crypt::HashCash::Coin->from_string($_) } split / /,$2 ],
 				  Requests           => [ map { Crypt::HashCash::CoinRequest->from_string($_) } split / /,$3 ]);
-    my @bcoins = map { $_->as_string } @$bcoins;
-    $ret = "@bcoins";
+    if ($bcoins =~ /^-E/) {
+      $ret = $bcoins;
+    }
+    else {
+      my @bcoins = map { $_->as_string } @$bcoins;
+      $ret = "@bcoins";
+    }
   }
   return ($ret, $preret, $sendto, $sendamt);
 }
@@ -460,8 +470,8 @@ Crypt::HashCash::Vault::Bitcoin - Bitcoin Vault for HashCash Digital Cash
 
 =head1 VERSION
 
- $Revision: 1.121 $
- $Date: Wed Jun 14 11:55:20 PDT 2017 $
+ $Revision: 1.122 $
+ $Date: Thu Jun 15 19:09:17 PDT 2017 $
 
 =head1 SYNOPSIS
 
